import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListImpersonationRolesRequest, ListImpersonationRolesResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link ListImpersonationRolesCommand}.
 */
export interface ListImpersonationRolesCommandInput extends ListImpersonationRolesRequest {
}
/**
 * @public
 *
 * The output of {@link ListImpersonationRolesCommand}.
 */
export interface ListImpersonationRolesCommandOutput extends ListImpersonationRolesResponse, __MetadataBearer {
}
declare const ListImpersonationRolesCommand_base: {
    new (input: ListImpersonationRolesCommandInput): import("@smithy/smithy-client").CommandImpl<ListImpersonationRolesCommandInput, ListImpersonationRolesCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListImpersonationRolesCommandInput): import("@smithy/smithy-client").CommandImpl<ListImpersonationRolesCommandInput, ListImpersonationRolesCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists all the impersonation roles for the given WorkMail organization.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, ListImpersonationRolesCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, ListImpersonationRolesCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // ListImpersonationRolesRequest
 *   OrganizationId: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 *   MaxResults: Number("int"),
 * };
 * const command = new ListImpersonationRolesCommand(input);
 * const response = await client.send(command);
 * // { // ListImpersonationRolesResponse
 * //   Roles: [ // ImpersonationRoleList
 * //     { // ImpersonationRole
 * //       ImpersonationRoleId: "STRING_VALUE",
 * //       Name: "STRING_VALUE",
 * //       Type: "FULL_ACCESS" || "READ_ONLY",
 * //       DateCreated: new Date("TIMESTAMP"),
 * //       DateModified: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListImpersonationRolesCommandInput - {@link ListImpersonationRolesCommandInput}
 * @returns {@link ListImpersonationRolesCommandOutput}
 * @see {@link ListImpersonationRolesCommandInput} for command's `input` shape.
 * @see {@link ListImpersonationRolesCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 * @public
 */
export declare class ListImpersonationRolesCommand extends ListImpersonationRolesCommand_base {
}
