import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListMobileDeviceAccessRulesRequest, ListMobileDeviceAccessRulesResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, WorkMailClientResolvedConfig } from "../WorkMailClient";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link ListMobileDeviceAccessRulesCommand}.
 */
export interface ListMobileDeviceAccessRulesCommandInput extends ListMobileDeviceAccessRulesRequest {
}
/**
 * @public
 *
 * The output of {@link ListMobileDeviceAccessRulesCommand}.
 */
export interface ListMobileDeviceAccessRulesCommandOutput extends ListMobileDeviceAccessRulesResponse, __MetadataBearer {
}
declare const ListMobileDeviceAccessRulesCommand_base: {
    new (input: ListMobileDeviceAccessRulesCommandInput): import("@smithy/smithy-client").CommandImpl<ListMobileDeviceAccessRulesCommandInput, ListMobileDeviceAccessRulesCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListMobileDeviceAccessRulesCommandInput): import("@smithy/smithy-client").CommandImpl<ListMobileDeviceAccessRulesCommandInput, ListMobileDeviceAccessRulesCommandOutput, WorkMailClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the mobile device access rules for the specified WorkMail organization.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { WorkMailClient, ListMobileDeviceAccessRulesCommand } from "@aws-sdk/client-workmail"; // ES Modules import
 * // const { WorkMailClient, ListMobileDeviceAccessRulesCommand } = require("@aws-sdk/client-workmail"); // CommonJS import
 * const client = new WorkMailClient(config);
 * const input = { // ListMobileDeviceAccessRulesRequest
 *   OrganizationId: "STRING_VALUE", // required
 * };
 * const command = new ListMobileDeviceAccessRulesCommand(input);
 * const response = await client.send(command);
 * // { // ListMobileDeviceAccessRulesResponse
 * //   Rules: [ // MobileDeviceAccessRulesList
 * //     { // MobileDeviceAccessRule
 * //       MobileDeviceAccessRuleId: "STRING_VALUE",
 * //       Name: "STRING_VALUE",
 * //       Description: "STRING_VALUE",
 * //       Effect: "ALLOW" || "DENY",
 * //       DeviceTypes: [ // DeviceTypeList
 * //         "STRING_VALUE",
 * //       ],
 * //       NotDeviceTypes: [
 * //         "STRING_VALUE",
 * //       ],
 * //       DeviceModels: [ // DeviceModelList
 * //         "STRING_VALUE",
 * //       ],
 * //       NotDeviceModels: [
 * //         "STRING_VALUE",
 * //       ],
 * //       DeviceOperatingSystems: [ // DeviceOperatingSystemList
 * //         "STRING_VALUE",
 * //       ],
 * //       NotDeviceOperatingSystems: [
 * //         "STRING_VALUE",
 * //       ],
 * //       DeviceUserAgents: [ // DeviceUserAgentList
 * //         "STRING_VALUE",
 * //       ],
 * //       NotDeviceUserAgents: [
 * //         "STRING_VALUE",
 * //       ],
 * //       DateCreated: new Date("TIMESTAMP"),
 * //       DateModified: new Date("TIMESTAMP"),
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListMobileDeviceAccessRulesCommandInput - {@link ListMobileDeviceAccessRulesCommandInput}
 * @returns {@link ListMobileDeviceAccessRulesCommandOutput}
 * @see {@link ListMobileDeviceAccessRulesCommandInput} for command's `input` shape.
 * @see {@link ListMobileDeviceAccessRulesCommandOutput} for command's `response` shape.
 * @see {@link WorkMailClientResolvedConfig | config} for WorkMailClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>One or more of the input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link OrganizationNotFoundException} (client fault)
 *  <p>An operation received a valid organization identifier that either doesn't belong or
 *          exist in the system.</p>
 *
 * @throws {@link OrganizationStateException} (client fault)
 *  <p>The organization must have a valid state to perform certain
 *          operations on the organization or its members.</p>
 *
 * @throws {@link WorkMailServiceException}
 * <p>Base exception class for all service exceptions from WorkMail service.</p>
 *
 * @public
 */
export declare class ListMobileDeviceAccessRulesCommand extends ListMobileDeviceAccessRulesCommand_base {
}
